# Table of Contents

- [enabling-discovered-flows](<./enabling-discovered-flows.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Enabling Discovered Flows](<./Enabling-Discovered-Flows.md>)
  - [Overview](<./Enabling-Discovered-Flows/Overview.md>)
  - [How Flow Discovery Works](<./Enabling-Discovered-Flows/How-Flow-Discovery-Works.md>)
  - [Prerequisites](<./Enabling-Discovered-Flows/Prerequisites.md>)
  - [Step 1: Update the SAP Cloud ALM Service Key Configuration](<./Enabling-Discovered-Flows/Step-1-Update-the-SAP-Cloud-ALM-Service-Key-Configuration.md>)
  - [Step 2: Enable Discovered Flows in SAP LeanIX](<./Enabling-Discovered-Flows/Step-2-Enable-Discovered-Flows-in-SAP-LeanIX.md>)
  - [Step 3: Verify Sync and View Discovered Items](<./Enabling-Discovered-Flows/Step-3-Verify-Sync-and-View-Discovered-Items.md>)
  - [Understanding Discovered Flow Items](<./Enabling-Discovered-Flows/Understanding-Discovered-Flow-Items.md>)
  - [Working with Discovered Flows](<./Enabling-Discovered-Flows/Working-with-Discovered-Flows.md>)
  - [Troubleshooting](<./Enabling-Discovered-Flows/Troubleshooting.md>)
